@@ -210,8 +210,10 @@ class MerkDevice(base_dev.BaseDevice):
                     if not ctx.is_open():
                         raise
             # 08_11
-            for name, factor, bwri_src in self.fn_08_11_:
-                bwri = calc_bwri(bwri_src)
+            for x in self.fn_08_11_:
+                name = x['tag']
+                factor = x['f']
+                bwri = calc_bwri(x['bwri'])
 
                 comment = 'Read {}'.format(name)
                 try:
